Trait gstreamer:: prelude:: GhostPadExt
source · pub trait GhostPadExt: IsA<GhostPad> + Sealed + 'static {
// Provided methods
fn target(&self) -> Option<Pad> { ... }
fn set_target(
&self,
newtarget: Option<&impl IsA<Pad>>,
) -> Result<(), BoolError> { ... }
}Provided Methods
sourcefn set_target(&self, newtarget: Option<&impl IsA<Pad>>) -> Result<(), BoolError>
fn set_target(&self, newtarget: Option<&impl IsA<Pad>>) -> Result<(), BoolError>
Set the new target of the ghostpad self. Any existing target
is unlinked and links to the new target are established. if newtarget is
None the target will be cleared.
newtarget
the new pad target
Returns
true if the new target could be set. This function
can return false when the internal pads could not be linked.
Object Safety
This trait is not object safe.