BaseTransformExtManual

Trait BaseTransformExtManual 

pub trait BaseTransformExtManual: IsA<BaseTransform> + 'static {
    // Provided methods
    fn allocator(&self) -> (Option<Allocator>, AllocationParams) { ... }
    fn set_allocator(
        &self,
        pool: Option<impl IsA<BufferPool>>,
        allocator: Option<impl IsA<Allocator>>,
        params: Option<&AllocationParams>,
        query: Option<Allocation<Query>>,
    ) -> Result<(), LoggableError> { ... }
    fn segment(&self) -> Segment { ... }
    fn sink_pad(&self) -> &Pad { ... }
    fn src_pad(&self) -> &Pad { ... }
}

Provided Methods

fn allocator(&self) -> (Option<Allocator>, AllocationParams)

Lets BaseTransform sub-classes know the memory allocator used by the base class and its params.

Unref the allocator after use.

Returns
allocator

the gst::Allocator used

params

the gst::AllocationParams of allocator

fn set_allocator( &self, pool: Option<impl IsA<BufferPool>>, allocator: Option<impl IsA<Allocator>>, params: Option<&AllocationParams>, query: Option<Allocation<Query>>, ) -> Result<(), LoggableError>

Allows BaseTransform sub-classes to set the buffer pool, memory allocator, its params and the query if they originate from an Allocation GstQuery.

pool

the gst::BufferPool

allocator

the gst::Allocator

params

the gst::AllocationParams of allocator

query

the Allocation GstQuery if any

Returns

TRUE on success or FALSE if buffer pool activation failed

fn segment(&self) -> Segment

fn sink_pad(&self) -> &Pad

fn src_pad(&self) -> &Pad

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors