pub struct ElementPropertiesMapItemBuilder { /* private fields */ }Implementations
sourceimpl ElementPropertiesMapItemBuilder
impl ElementPropertiesMapItemBuilder
sourcepub fn field(
self,
property_name: impl IntoGStr,
value: impl Into<Value> + Send,
) -> Self
pub fn field( self, property_name: impl IntoGStr, value: impl Into<Value> + Send, ) -> Self
Sets property property_name to the given value value.
Overrides any default or previously defined value for property_name.
sourcepub fn field_if(
self,
name: impl IntoGStr,
value: impl Into<Value> + Send,
predicate: bool,
) -> Self
pub fn field_if( self, name: impl IntoGStr, value: impl Into<Value> + Send, predicate: bool, ) -> Self
Sets field name to the given inner value if the predicate evaluates to true.
This has no effect if the predicate evaluates to false,
i.e. default or previous value for name is kept.
sourcepub fn field_if_some(
self,
name: impl IntoGStr,
value: Option<impl Into<Value> + Send>,
) -> Self
pub fn field_if_some( self, name: impl IntoGStr, value: Option<impl Into<Value> + Send>, ) -> Self
Sets field name to the given inner value if value is Some.
This has no effect if the value is None, i.e. default or previous value for name is kept.
sourcepub fn field_from_iter<V: ValueType + Into<Value> + FromIterator<SendValue> + Send>(
self,
name: impl IntoGStr,
iter: impl IntoIterator<Item = impl ToSendValue>,
) -> Self
pub fn field_from_iter<V: ValueType + Into<Value> + FromIterator<SendValue> + Send>( self, name: impl IntoGStr, iter: impl IntoIterator<Item = impl ToSendValue>, ) -> Self
Sets field name using the given ValueType V built from iter’s the Items.
Overrides any default or previously defined value for name.
sourcepub fn field_if_not_empty<V: ValueType + Into<Value> + FromIterator<SendValue> + Send>(
self,
name: impl IntoGStr,
iter: impl IntoIterator<Item = impl ToSendValue>,
) -> Self
pub fn field_if_not_empty<V: ValueType + Into<Value> + FromIterator<SendValue> + Send>( self, name: impl IntoGStr, iter: impl IntoIterator<Item = impl ToSendValue>, ) -> Self
Sets field name using the given ValueType V built from iter’s Items, if iter` is not empty.
This has no effect if iter is empty, i.e. previous value for name is unchanged.
pub fn field_value(self, property_name: &str, value: SendValue) -> Self
pub fn field_value_if_some( self, property_name: &str, value: Option<SendValue>, ) -> Self
pub fn build(self) -> ElementPropertiesMapItem