Struct TagLicense Flags
Source pub struct TagLicenseFlags(/* private fields */);Expand description
See http://creativecommons.org/ns for more information.
Implementations
Sourceimpl TagLicenseFlags
impl TagLicenseFlags
Sourcepub const PERMITS_REPRODUCTION: Self
pub const PERMITS_REPRODUCTION: Self
making multiple copies is allowed
Sourcepub const PERMITS_DISTRIBUTION: Self
pub const PERMITS_DISTRIBUTION: Self
distribution, public display and public performance are allowed
Sourcepub const PERMITS_DERIVATIVE_WORKS: Self
pub const PERMITS_DERIVATIVE_WORKS: Self
distribution of derivative works is allowed
Sourcepub const PERMITS_SHARING: Self
pub const PERMITS_SHARING: Self
commercial derivatives are allowed, but only non-commercial distribution is allowed
Sourcepub const REQUIRES_NOTICE: Self
pub const REQUIRES_NOTICE: Self
copyright and license notices must be kept intact
Sourcepub const REQUIRES_ATTRIBUTION: Self
pub const REQUIRES_ATTRIBUTION: Self
credit must be given to copyright holder and/or author
Sourcepub const REQUIRES_SHARE_ALIKE: Self
pub const REQUIRES_SHARE_ALIKE: Self
derivative works must be licensed under the same terms or compatible terms as the original work
Sourcepub const REQUIRES_SOURCE_CODE: Self
pub const REQUIRES_SOURCE_CODE: Self
source code (the preferred form for making modifications) must be provided when exercising some rights granted by the license
Sourcepub const REQUIRES_COPYLEFT: Self
pub const REQUIRES_COPYLEFT: Self
derivative and combined works must be licensed under specified terms, similar to those of the original work
Sourcepub const REQUIRES_LESSER_COPYLEFT: Self
pub const REQUIRES_LESSER_COPYLEFT: Self
derivative works must be licensed under specified terms, with at least the same conditions as the original work; combinations with the work may be licensed under different terms
Sourcepub const PROHIBITS_COMMERCIAL_USE: Self
pub const PROHIBITS_COMMERCIAL_USE: Self
exercising rights for commercial purposes is prohibited
Sourcepub const PROHIBITS_HIGH_INCOME_NATION_USE: Self
pub const PROHIBITS_HIGH_INCOME_NATION_USE: Self
use in a non-developing country is prohibited
Sourcepub const CREATIVE_COMMONS_LICENSE: Self
pub const CREATIVE_COMMONS_LICENSE: Self
this license was created by the Creative Commons project
Sourcepub const FREE_SOFTWARE_FOUNDATION_LICENSE: Self
pub const FREE_SOFTWARE_FOUNDATION_LICENSE: Self
this license was created by the Free Software Foundation (FSF)
Sourceimpl TagLicenseFlags
impl TagLicenseFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl TagLicenseFlags
impl TagLicenseFlags
Sourcepub const fn iter(&self) -> Iter<TagLicenseFlags>
pub const fn iter(&self) -> Iter<TagLicenseFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TagLicenseFlags>
pub const fn iter_names(&self) -> IterNames<TagLicenseFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.